import fire
import copy
from domnibus import Domnibus

class DomnibusMeta(type):
    def __init__(cls, name, bases, attrs, **kwargs):
        allowed_methods = Domnibus.allowed_methods()
        cls.list = cls.ls = ['{} <domain>'.format(am) for am in allowed_methods]

        for method in allowed_methods:
            setattr(cls, method, (lambda method: lambda self, domain: Domnibus(domain)[method])(method))

        return super(DomnibusMeta, cls).__init__(name, bases, attrs)


class DomnibusCLI(object):
    __metaclass__ = DomnibusMeta

def cli():
    fire.Fire(DomnibusCLI)

if __name__ == '__main__':
    cli()



import os
import sys

from pip.req import parse_requirements
from pip.download import PipSession
from setuptools import find_packages

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

# reading requirements
install_reqs = parse_requirements('requirements.txt', session=PipSession())
reqs = [str(ir.req) for ir in install_reqs]
sys.path.insert(0, os.path.dirname(__file__))
version = '1.0.4'
setup(
    name='domnibus',
    author='cyriac',
    author_email='me@cyriacthomas.com',
    version=version,
    packages=find_packages(),
    install_requires=reqs,
    include_package_data=True,
    license='MIT',
    description='Get all possible information about a domain',
    keywords = ['domnibus', 'domni', 'whois', 'ssl', 'nameserver', 'dns'],
    url='https://github.com/cyriac/domnibus',
    download_url = 'https://github.com/cyriac/domnibus/archive/v{version}.tar.gz'.format(version=version),
    entry_points='''
        [console_scripts]
        domni=domnibus.cli:cli
    '''
)



def camel_case_to_lower_case_underscore(string):
    """
    Split string by upper case letters.
 
    F.e. useful to convert camel case strings to underscore separated ones.
 
    @return words (list)
    """
    if not string.isupper():
        words = []
        from_char_position = 0
        for current_char_position, char in enumerate(string):
            if char.isupper() and from_char_position < current_char_position:
                words.append(string[from_char_position:current_char_position].lower())
                from_char_position = current_char_position
        words.append(string[from_char_position:].lower())
        string = '_'.join(words)

    return string

def unify_key_formats(response_dict):
    value = {}
    for k, v in response_dict.items():
        value[camel_case_to_lower_case_underscore(k)] = v
    return value